@import "mediawiki.mixins";

/* Element colours */
@bold-bkg: #f3f3f3;
@bold-border: #e0e0e0;
@soft-bkg: #f9f9f9;
@soft-border: #eee;

@text-grey: #666;
@link-grey: #444;
@fluff-grey: #888;

@header-grey: @link-grey;

/* Not exactly variables */
.widths() {
	max-width: 1050px;
	*width: 900px;
}

.generic-dropdown() {
	position: absolute;
	background: #fff;
	top: 100%;
	left: 0;
	padding: .75em 2em;
	border: solid 1px @soft-border;
	box-shadow: 0 2px 4px rgba(0,0,0,.05);
	width: 10em;
	text-align: left;
	z-index: 5;
	line-height: 1.1em;

	ul {
		margin: 0;
		padding: 0;
		list-style: none;
	}

	li {
		margin: .75em 0;
	}

	a {
		display: block;
	}
}
